@@ -22,7 +22,13 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+#include <glib.h>
+#include <gtk/gtkwidget.h>
+#include <libgnome/libgnome.h>
+#include <libgnomeui/gnome-font-picker.h>
+#include <libgnomeui/gnome-paper-selector.h>
+#include <libgnomeui/gnome-color-picker.h>
+#include <libgnomeui/gnome-propertybox.h>
 #include <glade/glade.h>
 
 #include "prefs.h"
@@ -131,15 +137,9 @@ apply_cb (GnomePropertyBox *pbox, gint page, gpointer data)
 		
 	}
 
-#ifdef ENABLE_SPLIT_SCREEN
-	settings->splitscreen = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (splitscreen));
-#endif
-
-#if 0 /* FIXME We are leaking memory here but it is crashing, I will continue tomorrow. */
-	g_print("Font : %s\n:", settings->font);
 	if (settings->font)
 		g_free (settings->font);
-#endif	
+	
 	settings->font = g_strdup (gnome_font_picker_get_font_name (GNOME_FONT_PICKER (defaultfont)));
 
 	if (gtk_radio_group_get_selected (GTK_RADIO_BUTTON(print_orientation_portrait_radio_button)->group)==0)
@@ -154,16 +154,18 @@ apply_cb (GnomePropertyBox *pbox, gint page, gpointer data)
 	if (strcmp( "custom", gnome_paper_selector_get_name( GNOME_PAPER_SELECTOR (paperselector)))==0)
 	{
 		g_warning ("Custom paper sizes not yet supported. Setting paper size to default\n");
-		settings->papersize = strdup (gnome_paper_name_default());
+		settings->papersize = g_strdup (gnome_paper_name_default());
 	}
 	else
-		settings->papersize = strdup (gnome_paper_selector_get_name( GNOME_PAPER_SELECTOR (paperselector)));
+		settings->papersize = g_strdup (gnome_paper_selector_get_name( GNOME_PAPER_SELECTOR (paperselector)));
 
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (print_lines)))
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (print_lines))) {
 		settings->print_lines = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (print_lines_spin_button));
+	}
 	else
+	{
 		settings->print_lines = 0;
-	
+	}
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (undo_levels)))
 		settings->undo_levels = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (undo_levels_spin_button));
 	else
@@ -404,7 +406,8 @@ prepare_fontscolors_page (GladeXML *gui)
 
 	/* setup the initial states */
 	if (mdi->active_view)
-		style = gtk_style_copy (gtk_widget_get_style (GEDIT_VIEW (mdi->active_view)->text));
+		style = gtk_style_copy (gtk_widget_get_style (
+			GTK_WIDGET (GEDIT_VIEW (mdi->active_view)->text)));
 	else
 		style = gtk_style_new ();
 
@@ -521,7 +524,8 @@ prepare_pagesize_page (GladeXML *gui)
 				       settings->papersize);
 
 	/* connect signals */
-	gtk_signal_connect(GTK_OBJECT( GTK_COMBO( GNOME_PAPER_SELECTOR(paperselector)->paper)->entry), "changed",
+	gtk_signal_connect(GTK_OBJECT( GTK_COMBO( GNOME_PAPER_SELECTOR(paperselector)->paper)->entry),
+			   "changed",
 			   GTK_SIGNAL_FUNC (prefs_changed), NULL);
 			   
 }
@@ -537,7 +541,7 @@ gedit_prefs_notebook_switch_page (GtkWidget *widget, gpointer data)
 static void
 dialog_prefs_impl (GladeXML *gui)
 {
-	static GnomeHelpMenuEntry help_entry = { NULL, "prefs.html" };
+	static GnomeHelpMenuEntry help_entry = { NULL, "prefs" };
 
 	gedit_debug (DEBUG_PREFS, "");
 
@@ -570,7 +574,7 @@ dialog_prefs_impl (GladeXML *gui)
 
 	help_entry.name = gnome_app_id;
 	gtk_signal_connect (GTK_OBJECT (propertybox),"help",
-			    GTK_SIGNAL_FUNC (gnome_help_pbox_goto), &help_entry);
+			    GTK_SIGNAL_FUNC (gnome_help_pbox_display), &help_entry);
 #ifdef USE_NOTEBBOK	
 	gtk_signal_connect (GTK_OBJECT (notebook),"switch_page",
 			    GTK_SIGNAL_FUNC (gedit_prefs_notebook_switch_page), NULL);
@@ -584,7 +588,7 @@ dialog_prefs_impl (GladeXML *gui)
 }
 
 void
-dialog_prefs (void)
+gedit_dialog_prefs (void)
 {
 	static GladeXML *gui = NULL;
 
